.. :changelog:

History
-------

0.2.1 (2017-10-30)
++++++++++++++++++

* Fixed that the admin would give a 500 when you only set the maintenance_from.

0.2.0 (2017-10-26)
++++++++++++++++++

* Now the admin exclude will work with i18n urls.
* MAINTENANCE_EXCLUDE_ADMIN_URLS is now a setting (default=True)
* MAINTENANCE_EXCLUDE_SUPER_USER is now a setting (default=False)
* MAINTENANCE_EXCLUDE_STAFF_USER is now a setting (default=False)

0.1.0 (2017-10-26)
++++++++++++++++++

* First release on PyPI.
